﻿local function HumanReadableNumber(num, unit, suffix)
	if num == 0 then return num end
	if not unit then unit = 1000 end
	if num < unit and num > -unit then return num end
	if not suffix then suffix = 'kmbtq' end
	local negative = num < 0
	if negative then
		negative = true
		num = abs(num)
	end
	local exp = floor(log(num) / log(unit))
	if exp > strlen(suffix) then return num end
	return format((negative and '-' or '+') .. '%.0f%s', num/unit^exp, strsub(suffix, exp, exp))
end

local function UpdateFrameStatusText(frame)
	if not frame.optionTable.displayStatusText then
		frame.statusText:Hide()
	elseif not UnitIsConnected(frame.unit) or UnitIsDeadOrGhost(frame.displayedUnit) then
		return
	elseif frame.optionTable.healthText == "health" then
		local health = UnitHealth(frame.displayedUnit) + (UnitGetTotalAbsorbs(frame.displayedUnit) or 0)
		if health ~= 0 then
			frame.statusText:SetText(HumanReadableNumber(health))
			frame.statusText:Show()
		else
			frame.statusText:Hide()
		end
	elseif frame.optionTable.healthText == "losthealth" then
		local health = UnitHealth(frame.displayedUnit) - UnitHealthMax(frame.displayedUnit) + (UnitGetTotalAbsorbs(frame.displayedUnit) or 0)
		if health ~= 0 then
			frame.statusText:SetText(HumanReadableNumber(health))
			frame.statusText:Show()
		else
			frame.statusText:Hide()
		end
	elseif frame.optionTable.healthText == "perc" and UnitHealthMax(frame.displayedUnit) > 0 then
		local health = UnitHealth(frame.displayedUnit) + (UnitGetTotalAbsorbs(frame.displayedUnit) or 0)
		local perc = math.ceil(100 * (health / UnitHealthMax(frame.displayedUnit)))
		if perc ~= 100 then
			frame.statusText:SetFormattedText("%d%%", perc)
			frame.statusText:Show()
		else
			frame.statusText:Hide()
		end
	end
end

hooksecurefunc("CompactUnitFrame_UpdateStatusText", UpdateFrameStatusText)
hooksecurefunc("CompactUnitFrame_UpdateHealPrediction", UpdateFrameStatusText)